#! /usr/bin/perl -w

# Most of this is shamelessly stolen from MiniVend's Makefile.PL.

# Copyright (C) 1999,2000 Stefan Hornburg

# Author: Stefan Hornburg <racke@linuxia.de>
# Maintainer: Stefan Hornburg <racke@linuxia.de>

# This file is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any
# later version.

# This file is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this file; see the file COPYING.  If not, write to the Free
# Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

use strict;
use ExtUtils::MakeMaker;

# Version of MiniMate
my $VERSION = '4.0.0.1';

# See if we have Term::ReadLine::Perl
my $TermRead;
eval {
		require Term::ReadLine;
		require Term::ReadLine::Perl;
		require Term::ReadKey;
		$TermRead = 1;
};
unless($@) {
	$ENV{PERL_RL} = 'Perl';
}

my $term; my $Prompt_sub;
if($TermRead) {
	$term = new Term::ReadLine 'MakeFile';
	$Prompt_sub = sub {
		my($prompt, $default) = @_;
		$prompt .= "[$default] "
			if defined $default && !$ENV{PERL_RL};
		return $term->readline($prompt, $default);
	};
}

sub copyright_prompt {

	print <<EOF;

 MiniMate V$VERSION
 
 Copyright 1998,1999,2000 by Michael J. Heins <mikeh\@minivend.com>
 Copyright 1999,2000 by Stefan Hornburg <racke\@linuxia.de>

 MiniMate is free under the terms of the GNU General Public License.

EOF
}

sub my_prompt {
    return &$Prompt_sub(@_)
        if defined $Prompt_sub;
    my($pr) = shift || '? ';
    my($def) = shift;
    my($ans);

    print $pr;
    print "[$def] " if $def;
    chomp($ans = <STDIN>);
    $ans ? $ans : $def;
}

sub initialize {
  my $realdir;
  my %X;
  
  &copyright_prompt();

  # possible installation directories 
  my @mvdirs = ("$ENV{HOME}/mvend", "/home/minivend",
			   "/usr/local/lib/minivend", "$ENV{HOME}/minivend");

  foreach my $mvdir (@ARGV, @mvdirs) {
	if (-f "$mvdir/minivend.cfg" or -f "$mvdir/minivend.cfg.dist") {
	  $realdir = $mvdir if -w $mvdir;
	  last;
	}
  }

  $realdir ||= $mvdirs[0];
  $realdir=my_prompt("Where is your MiniVend installed? ",$realdir);
  print "\n";
  $realdir =~ s:[\\/]\s*$::;

  $X{INSTALLARCHLIB}	= "$realdir/lib/MiniMate";
  $X{INSTALLPRIVLIB}	= "$realdir/lib/MiniMate";
  $X{INSTALLMAN1DIR}	= "$realdir/doc";
  $X{INSTALLMAN3DIR}	= "$realdir/doc";
  $X{INSTALLDIRS}     = "perl";
  $X{PREFIX}          = $realdir;
  return \%X;
}

sub MY::install {
	my $self = shift;
	my $new;

if ($^O !~ /win32/i)
  {
    $new = <<'EOF';
mm_install ::
	$(PERL) -MExtUtils::Manifest \
        -e '$$files = ExtUtils::Manifest::maniread();\
        ExtUtils::Manifest::manicopy ($$files, "$(INSTALLARCHLIB)");'
  
install :: all mm_install

EOF
  }
else
  {
$new = <<'EOF';
mm_install ::
	$(PERL) -MExtUtils::Manifest -e "$$files = ExtUtils::Manifest::maniread(); ExtUtils::Manifest::manicopy ($$files, '$(INSTALLARCHLIB)');"
  
install :: all mm_install

EOF
  }
	$_ = $self->MM::install;
	s/\ninstall :.*/$new/;
	$_;
}

sub MY::postamble
  {
	my @timearr = gmtime ();
	my $stamp = sprintf ("%d%02d%02d%02d", $timearr[5] + 1900,
						 $timearr[4] + 1, $timearr[3], $timearr[2]);
	
  "
MMLANGS=de_DE fr_FR it_IT ru_RU

localefiles:
	for lang in \$(MMLANGS); do \\
        mv locales/\$\$lang.cfg locales/\$\$lang.cfg.old; \\
		\$(INSTALLBIN)/localize -m locales/\$\$lang.cfg.old -l \$\$lang `find pages -type f` > locales/\$\$lang.cfg; \\
	done

snapshot:
	\$(MAKE) dist VERSION=$VERSION.$stamp
";
  }

WriteMakefile
  ('NAME' => 'MiniMate',
   'dist' => {COMPRESS => 'gzip', SUFFIX => 'gz'},
   'VERSION' => $VERSION,
   'CONFIGURE' => \&initialize
  );
			  
			   
# Local Variables:
# indent-tabs-mode: t
# End:  
